package de.hawhamburg.reachability.tools.feeder;


/**
 * Interface of threads that shall be notified by the {@link SensorDataFeeder}.<br><br>
 * 
 * This interfaces provides methods making a thread notifiable by the {@link SensorDataFeeder}.
 * 
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR} 
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public interface SensorDataFeederNotifiable {

    /**
     * Registers a new {@link SensorDataFeeder} as running simulation.
     * 
     * @param feeder    The {@link SensorDataFeeder} which shall be registered.
     */
    void registerSimulationFeeder(final SensorDataFeeder feeder);
    
    /**
     * Unregisters a {@link SensorDataFeeder} from this thread at the end of the simulation.
     * 
     * @param feeder    The {@link SensorDataFeeder} which shall be unregistered.
     */
    void unregisterSimulationFeeder(final SensorDataFeeder feeder);
}
